@@ -143,11 +143,6 @@ where
 
         ParentCache::new(cache_size, cache_entries, self)
     }
-
-    pub fn api_version(&self) -> ApiVersion {
-        self.api_version
-    }
-
     pub fn copy_parents_data_exp(
         &self,
         node: u32,
@@ -223,7 +218,7 @@ where
 
         // round 3 (9)
         hasher.input(&parents[..8]);
-        hasher.finish_with(&parents[8])
+        hasher.finish_with(parents[8])
     }
 
     fn copy_parents_data_inner(
