@@ -29,4 +29,4 @@ pub use encoding_proof::EncodingProof;
 pub use graph::{StackedBucketGraph, StackedGraph, EXP_DEGREE};
 pub use labeling_proof::LabelingProof;
 pub use params::*;
-pub use proof::{StackedDrg, TOTAL_PARENTS};
+pub use proof::{StackedDrg, TreeRElementData, TOTAL_PARENTS};
